@@ -18,7 +18,7 @@
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 define(
-['aloha/core', 'aloha/jquery', 'aloha/ext', 'util/class', 'aloha/console', 'vendor/jquery.store'],
+['aloha/core', 'aloha/jquery', 'aloha/ext', 'util/class', 'aloha/console', 'vendor/jquery.store', 'aloha/selection'],
 function(Aloha, jQuery, Ext, Class, console) {
 	
 	var GENTICS = window.GENTICS;
@@ -472,6 +472,11 @@ function(Aloha, jQuery, Ext, Class, console) {
 		 * the floating menu. If there is no config, tabs and groups will be generated programmatically
 		 */
 		fromConfig: false,
+		
+		/**
+		 * hide a tab
+		*/
+		hideTab: false,
 
 		/**
 		 * Initialize the floatingmenu
@@ -518,7 +523,6 @@ function(Aloha, jQuery, Ext, Class, console) {
 					this.pin = Aloha.settings.floatingmenu.pin;
 				}
 
-
 				if ( typeof Aloha.settings.floatingmenu.width !==
 				         'undefined' ) {
 					this.width = parseInt( Aloha.settings.floatingmenu.width,
@@ -1142,6 +1146,7 @@ function(Aloha, jQuery, Ext, Class, console) {
 			
 			// let the tabs layout themselves
 			jQuery.each(this.tabs, function(index, tab) {
+
 				// remember the active tab
 				if (tab.extPanel == activeExtTab) {
 					activeTab = tab;
@@ -1168,7 +1173,6 @@ function(Aloha, jQuery, Ext, Class, console) {
 						// this is the first visible tab (in case we need to switch to it)
 						firstVisibleTab = tab;
 					}
-
 					// check whether this visible tab is the last user activated tab and currently not active
 					if (that.userActivatedTab == tab.extPanel.title && tab.extPanel != activeExtTab) {
 						showUserActivatedTab = tab;
@@ -1182,6 +1186,15 @@ function(Aloha, jQuery, Ext, Class, console) {
 						that.extTabPanel.hideTabStripItem(tab.extPanel);
 					}
 				}
+
+				// hide a tab
+				if ( tab.label == that.hideTab ) {
+					that.extTabPanel.hideTabStripItem(tab.extPanel);
+
+					if ( activeExtTab.title == that.hideTab ) {
+						showUserActivatedTab = firstVisibleTab;
+					}
+				}
 			});
 
 			// check whether the last tab which was selected by the user is visible and not the active tab
@@ -1490,6 +1503,15 @@ function(Aloha, jQuery, Ext, Class, console) {
 		menu.setScope('Aloha.empty');
 	});
 	
+	Aloha.bind('aloha-selection-changed-before', function(event, rangeObject, originalEvent) {
+		// Only set the specific scope if an event was provided, which means
+		// that somehow an editable was selected
+		if (originalEvent !== undefined) {
+			// Initiallly set the scope to 'continuoustext'
+			menu.setScope('Aloha.continuoustext');
+		}
+	});
+
 	// set scope to empty if the user selectes a non contenteditable area
 	Aloha.bind('aloha-selection-changed', function() {
 		if ( !Aloha.Selection.isSelectionEditable() && !Aloha.Selection.isFloatingMenuVisible() ) {
@@ -1499,4 +1521,3 @@ function(Aloha, jQuery, Ext, Class, console) {
 	
 	return menu;
 });
-
