@@ -10,8 +10,8 @@
  *
  */
 define(
-['aloha/jquery', 'aloha/observable'],
-function(jQuery, Observable) {
+['aloha/jquery', 'aloha/observable', 'util/class'],
+function(jQuery, Observable, Class) {
 	
 
 	return Class.extend(Observable, {
@@ -34,7 +34,6 @@ function(jQuery, Observable) {
 
 		/**
 		 * @event unregister
-		 * @param odEntry
 		 * @param id
 		 */
 		unregister: function(id) {
