@@ -781,37 +781,39 @@ define([
 				 */
 				Aloha.bind('aloha-selection-changed', function(event, rangeObject, originalEvent) {
 					var config, foundMarkup;
+
 					if (originalEvent && originalEvent.target) {
 						// Check if the element is currently beeing resized
-						if (that.settings.ui.resizable && !jQuery(originalEvent.target).hasClass('ui-resizable-handle')) {
+						if (that.settings.ui.resizable &&
+							!jQuery(originalEvent.target).hasClass('ui-resizable-handle')) {
 							that.endResize();
 						}
 					}
 
 					if (Aloha.activeEditable !== null) {
 						foundMarkup = that.findImgMarkup( rangeObject );
-						//var config = that.getEditableConfig(Aloha.activeEditable.obj);
 						config = that.getEditableConfig(Aloha.activeEditable.obj);
+						//that.settings = this.settings = jQuery.extend(true, that.defaultSettings, config);
 
-						if (typeof config !== 'undefined' ) {
-							that.insertImgButton.show();
-						} else {
+						if ( jQuery.isEmpty(config) ) {
 							that.insertImgButton.hide();
 							return;
+						} else {
+							that.insertImgButton.show();
 						}
 
 						// Enable image specific ui components if the element is an image
 						if (foundMarkup) {
 							that.insertImgButton.hide();
 							FloatingMenu.setScope(that.name);
-							if (that.settings.ui.meta) {
+							if ( that.settings.ui.meta ) {
 								that.imgSrcField.setTargetObject(foundMarkup, 'src');
 								that.imgTitleField.setTargetObject(foundMarkup, 'title');
 							}
 							that.imgSrcField.focus();
 							FloatingMenu.activateTabOfButton('imgsrc');
 						} else {
-							if (that.settings.ui.meta) {
+							if ( that.settings.ui.meta) {
 								that.imgSrcField.setTargetObject(null);
 							}
 						}
@@ -834,6 +836,7 @@ define([
 					// Inital click on images will be handled here
 					// editable.obj.find('img').attr('_moz_resizing', false);
 					// editable.obj.find('img').contentEditable(false);
+					// @todo there's an issue when pressing the mouse button / shift key and release it... resizing does not stop on certain conditions. see: https://getsatisfaction.com/aloha_editor/topics/image_resizing-yfzk8
 					editable.obj.delegate( 'img', 'mouseup', function (event) {
 						that.clickImage(event);
 						event.stopPropagation();
@@ -1131,16 +1134,13 @@ define([
 				$('#' + that.imgResizeHeightField.id).val(that.imageObj.height());
 				$('#' + that.imgResizeWidthField.id).val(that.imageObj.width());
 
-
-				if (this.settings.ui.resizable) {
+				if ( this.settings.ui.resizable ) {
 					this.startResize();
 				}
-			
-			
+
 				if (this.settings.autoResize) {
 					this.autoResize();
 				}
-
 			},
 
 			/**
